==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-panel/plugin-desktopswitch/desktopswitch_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>DesktopSwitch</name>
    <message>
        <location filename="../../../desktopswitch.cpp" line="84"/>
        <source>Switch to desktop %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../desktopswitch.cpp" line="141"/>
        <location filename="../../../desktopswitch.cpp" line="151"/>
        <source>Desktop %1</source>
        <translation>桌面 %1</translation>
    </message>
</context>
<context>
    <name>DesktopSwitchConfiguration</name>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="14"/>
        <source>DesktopSwitch settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="46"/>
        <source>Number of rows:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="39"/>
        <source>Desktop labels:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="54"/>
        <source>Numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="59"/>
        <source>Names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="70"/>
        <source>Desktop names</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.13.0.orig.tar.xz: lxqt-l10n-0.13.0/lxqt-panel/plugin-desktopswitch/desktopswitch_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>DesktopSwitch</name>
    <message>
        <location filename="../../../desktopswitch.cpp" line="84"/>
        <source>Switch to desktop %1</source>
        <translation>切换至桌面 %1</translation>
    </message>
    <message>
        <location filename="../../../desktopswitch.cpp" line="141"/>
        <location filename="../../../desktopswitch.cpp" line="151"/>
        <source>Desktop %1</source>
        <translation>桌面 %1</translation>
    </message>
</context>
<context>
    <name>DesktopSwitchConfiguration</name>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="14"/>
        <source>DesktopSwitch settings</source>
        <translation>桌面切换设置</translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="46"/>
        <source>Number of rows:</source>
        <translation>行数:</translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="39"/>
        <source>Desktop labels:</source>
        <translation>桌面标签:</translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>外观</translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="54"/>
        <source>Numbers</source>
        <translation>数量</translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="59"/>
        <source>Names</source>
        <translation>名称</translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="70"/>
        <source>Desktop names</source>
        <translation>桌面名称</translation>
    </message>
</context>
</TS>
